==> goreleaser-1.9.2.tar.gz: goreleaser-1.9.2/www/docs/cookbooks/blog-posts.md <==
# Blog Posts

Tutorials made by the community.

<!-- please, keep A-Z sorting -->
- [Creating debs and rpms with Go](https://carlosbecker.com/posts/nfpm/)
- [Cross compile with CGO and GoReleaser](https://medium.com/@robdefeo/cross-compile-with-cgo-and-goreleaser-6af884731222?source=friends_link&sk=baf6553fa48cb0e28ea3519615f02576)
- [Drop ballast... How I reduced the size of minectl 🗺](https://blog.ediri.io/drop-ballast-how-i-reduced-the-size-of-minectl)
- [Fast and easy Go binaries delivery](https://carlosbecker.com/posts/goreleaser/)
- [GitHub Action for release your Go projects as fast and easily as possible](https://dev.to/koddr/github-action-for-release-your-go-projects-as-fast-and-easily-as-possible-20a2)
- [Go Release Automation with goreleaser + GitHub Actions](https://blog.toshima.ru/2019/10/20/go-release-automation-with-goreleaser.html)
- [GoReleaser + Drone + GitHub: Tutorial](https://medium.com/@fallion/goreleaser-drone-github-tutorial-9a150103cac0)
- [GoReleaser Docker Support](https://carlosbecker.com/posts/goreleaser-docker/)
- [GoReleaser: build and push Snapcraft packages from TravisCI](https://carlosbecker.com/posts/goreleaser-snap-travis/)
- [Multi-platform Docker images with GoReleaser and GitHub Actions](https://carlosbecker.com/posts/multi-platform-docker-images-goreleaser-gh-actions/)
- [Multi-platform Docker images with GoReleaser, Podman and GitHub Actions](https://carlosbecker.com/posts/goreleaser-actions-podman/)
- [Painless GitHub releases with Drone and GoReleaser](https://medium.com/@stepanvrany/painless-github-releases-with-drone-and-goreleaser-853bbbccd0c0)
- [Publishing dep/rpm packages with Goreleaser and Fury.io](https://netdevops.me/2021/building-and-publishing-deb/rpm-packages-with-goreleaser-and-gemfury/)
- [Shipping Rust Binaries with GoReleaser](https://medium.com/@jondot/shipping-rust-binaries-with-goreleaser-d5aa42a46be0)
- [Using GoReleaser includes feature](https://carlosbecker.com/posts/goreleaser-includes/)

!!! tip
    Click on the "Edit" button to add your page here.

==> goreleaser-1.17.1.tar.gz: goreleaser-1.17.1/www/docs/cookbooks/blog-posts.md <==
# Blog Posts

Tutorials made by the community.

<!-- please, keep A-Z sorting -->
- [Creating debs and rpms with Go](https://carlosbecker.com/posts/nfpm/)
- [Cross compile with CGO and GoReleaser](https://medium.com/@robdefeo/cross-compile-with-cgo-and-goreleaser-6af884731222?source=friends_link&sk=baf6553fa48cb0e28ea3519615f02576)
- [Cross-compiling a CGO project using Goreleaser](https://www.jvt.me/posts/2023/02/24/goreleaser-cgo-cross-compile/)
- [Drop ballast... How I reduced the size of minectl 🗺](https://blog.ediri.io/drop-ballast-how-i-reduced-the-size-of-minectl)
- [Fast and easy Go binaries delivery](https://carlosbecker.com/posts/goreleaser/)
- [GitHub Action for release your Go projects as fast and easily as possible](https://dev.to/koddr/github-action-for-release-your-go-projects-as-fast-and-easily-as-possible-20a2)
- [Go Release Automation with goreleaser + GitHub Actions](https://blog.toshima.ru/2019/10/20/go-release-automation-with-goreleaser.html)
- [GoReleaser + Drone + GitHub: Tutorial](https://medium.com/@fallion/goreleaser-drone-github-tutorial-9a150103cac0)
- [GoReleaser Docker Support](https://carlosbecker.com/posts/goreleaser-docker/)
- [GoReleaser: build and push Snapcraft packages from TravisCI](https://carlosbecker.com/posts/goreleaser-snap-travis/)
- [Multi-platform Docker images with GoReleaser and GitHub Actions](https://carlosbecker.com/posts/multi-platform-docker-images-goreleaser-gh-actions/)
- [Multi-platform Docker images with GoReleaser, Podman and GitHub Actions](https://carlosbecker.com/posts/goreleaser-actions-podman/)
- [Painless GitHub releases with Drone and GoReleaser](https://medium.com/@stepanvrany/painless-github-releases-with-drone-and-goreleaser-853bbbccd0c0)
- [Publishing dep/rpm packages with Goreleaser and Fury.io](https://netdevops.me/2021/building-and-publishing-debrpm-packages-with-goreleaser-and-gemfury/)
- [Shipping Rust Binaries with GoReleaser](https://medium.com/@jondot/shipping-rust-binaries-with-goreleaser-d5aa42a46be0)
- [Using GoReleaser includes feature](https://carlosbecker.com/posts/goreleaser-includes/)

!!! tip
    Click on the "Edit" button to add your page here.
